﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace CodeGarage.it.Euro2012.Web.Mobile
{
    public class ManifestResult : FileResult
    {

        public string Version { get; set; }

        public IEnumerable<string> CacheSection { get; set; }
        public IEnumerable<string> NetworkSection { get; set; }
        public Dictionary<string, string> FallbackSection { get; set; }

        public ManifestResult(string version)
            : base("text/cache-manifest")
        {
            CacheSection = new List<string>();
            NetworkSection = new List<string>();
            FallbackSection = new Dictionary<string, string>();
            Version = version;
        }

        protected override void WriteFile(HttpResponseBase response)
        {
            response.Output.WriteLine("CACHE MANIFEST");
            response.Output.WriteLine("#Version:" + Version ?? string.Empty);
            response.Output.WriteLine("#ResourcesCount:" + CacheSection.Count());
            response.Output.WriteLine("CACHE:");
            foreach (var cacheResource in CacheSection)
            {
                response.Output.WriteLine(cacheResource);
            }
            
            response.Output.WriteLine();
            response.Output.WriteLine("NETWORK:");
            foreach (var networkResource in NetworkSection)
            {
                response.Output.WriteLine(networkResource);
            }
           
            response.Output.WriteLine();
            response.Output.WriteLine("FALLBACK:");
            foreach (var fallbackResource in FallbackSection)
                response.Output.WriteLine(string.Format("{0} {1}", fallbackResource.Key + fallbackResource.Value));

        }


    }

}